==> shardingsphere-db-discovery-distsql-statement-5.1.2-sources.jar: org/apache/shardingsphere/dbdiscovery/distsql/parser/statement/CreateDatabaseDiscoveryRuleStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.dbdiscovery.distsql.parser.statement;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.distsql.parser.subject.impl.DatabaseDiscoverySubjectSupplier;
import org.apache.shardingsphere.dbdiscovery.distsql.parser.segment.AbstractDatabaseDiscoverySegment;
import org.apache.shardingsphere.distsql.parser.statement.rdl.create.CreateRuleStatement;

import java.util.Collection;

/**
 * Create database discovery rule statement.
 */
@RequiredArgsConstructor
@Getter
public final class CreateDatabaseDiscoveryRuleStatement extends CreateRuleStatement implements DatabaseDiscoverySubjectSupplier {
    
    private final Collection<AbstractDatabaseDiscoverySegment> rules;
}

==> shardingsphere-db-discovery-distsql-statement-5.3.1-sources.jar: org/apache/shardingsphere/dbdiscovery/distsql/parser/statement/CreateDatabaseDiscoveryRuleStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.dbdiscovery.distsql.parser.statement;

import lombok.Getter;
import org.apache.shardingsphere.dbdiscovery.distsql.parser.segment.AbstractDatabaseDiscoverySegment;
import org.apache.shardingsphere.distsql.parser.statement.rdl.create.CreateRuleStatement;

import java.util.Collection;

/**
 * Create database discovery rule statement.
 */
@Getter
public final class CreateDatabaseDiscoveryRuleStatement extends CreateRuleStatement {
    
    private final Collection<AbstractDatabaseDiscoverySegment> rules;
    
    public CreateDatabaseDiscoveryRuleStatement(final boolean ifNotExists, final Collection<AbstractDatabaseDiscoverySegment> rules) {
        super(ifNotExists);
        this.rules = rules;
    }
}
